@@ -5,6 +5,7 @@ from bs4 import BeautifulSoup
 import json
 
 baseURL = "https://nn3.freenet.de/clevertanken/main.php?cm=1"
+baseURL = "http://130.61.217.10/main.php?cm=1"
 autogas = "Autogas"
 diesel = "Diesel"
 erdgas = "Erdgas"
@@ -14,7 +15,7 @@ normal = "Normal"
 
 class ITBObject:
     def __init__(self):
-        self.version = "1.0.8"
+        self.version = "1.0.12"
         self.author = "Ludy87"
         self.project = "Ich tanke billig"
         self.page = "https://www.astra-g.org/"
@@ -68,33 +69,36 @@ def getStations(kraftstoff = diesel, place = '123', limit = '-1', asJson = False
             colErg3 = row.find('td', {"class": "colErg3"})
 
             colErg1_a = colErg1.getText().strip().split('<br>')[0].split('\n')
-            stationName = colErg1_a[0].strip()
-            street = colErg1_a[1].strip()
-            place = colErg1_a[2].strip()
-            plz = place.split()[0]
-            ort = place.split()[1]
+            if len(colErg1_a) < 3:
+                me.status = {"error": 403}
+            else:
+                stationName = colErg1_a[0].strip()
+                street = colErg1_a[1].strip()
+                place = colErg1_a[2].strip()
+                plz = place.split()[0]
+                ort = place.split()[1]
 
-            price = colErg2.getText().strip()
+                price = colErg2.getText().strip()
 
-            reloaded = colErg3.getText().strip().split('<br>')[0].split('\n')
-            reloaded = reloaded[1].strip() + " " + reloaded[0].strip()
-            sum = stationName + street + place
-            sum = hashlib.md5(sum.encode()).hexdigest()
-            json_data = {
-                "id": sum,
-                "station_name": stationName,
-                "street": street,
-                "place": ort,
-                "plz": plz,
-                "price": price,
-                "reloaded": reloaded,
-                "fuel": kraftstoff,
-                "pos": i +1,
-            }
-            if (limit == str(i)) and (limit != '-1'):
-                break
-            i += 1
-            me.stations.append(json_data)
+                reloaded = colErg3.getText().strip().split('<br>')[0].split('\n')
+                reloaded = reloaded[1].strip() + " " + reloaded[0].strip()
+                sum = stationName + street + place
+                sum = hashlib.md5(sum.encode()).hexdigest()
+                json_data = {
+                    "id": sum,
+                    "station_name": stationName,
+                    "street": street,
+                    "place": ort,
+                    "plz": plz,
+                    "price": price,
+                    "reloaded": reloaded,
+                    "fuel": kraftstoff,
+                    "pos": i +1,
+                }
+                if (limit == str(i)) and (limit != '-1'):
+                    break
+                i += 1
+                me.stations.append(json_data)
     if asJson:
         return me.toJSON()
     else:
